@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use mro;
 
-our $VERSION = '3.16';
+our $VERSION = '3.17';
 
 require Storable;
 require Carp;
@@ -347,8 +347,8 @@ sub discover_schema {
     $self->set_columns(
         map {
             $_->name => defined $_->column_def
-              ? ({default => $_->column_def =~ /^''/ ? '' : $_->column_def })
-              : ()
+              ? ({default => $_->column_def =~ /^''/ ? '' : $_->column_def})
+              : ($_->is_nullable ? {default => undef, is_null => 1} : ())
         } $table->columns
     );
     $self->set_primary_key(map { $_->name } $table->primary_key);
